==> cloudfront-1.104.0-sources.jar: software/amazon/awscdk/services/cloudfront/CfnFunctionProps.java <==
package software.amazon.awscdk.services.cloudfront;

/**
 * Properties for defining a `AWS::CloudFront::Function`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.29.0 (build 41df200)", date = "2021-05-14T22:40:15.998Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudfront.$Module.class, fqn = "@aws-cdk/aws-cloudfront.CfnFunctionProps")
@software.amazon.jsii.Jsii.Proxy(CfnFunctionProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnFunctionProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::CloudFront::Function.Name`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getName();

    /**
     * `AWS::CloudFront::Function.AutoPublish`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getAutoPublish() {
        return null;
    }

    /**
     * `AWS::CloudFront::Function.FunctionCode`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getFunctionCode() {
        return null;
    }

    /**
     * `AWS::CloudFront::Function.FunctionConfig`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getFunctionConfig() {
        return null;
    }

    /**
     * `AWS::CloudFront::Function.FunctionMetadata`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getFunctionMetadata() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnFunctionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnFunctionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnFunctionProps> {
        private java.lang.String name;
        private java.lang.Object autoPublish;
        private java.lang.String functionCode;
        private java.lang.Object functionConfig;
        private java.lang.Object functionMetadata;

        /**
         * Sets the value of {@link CfnFunctionProps#getName}
         * @param name `AWS::CloudFront::Function.Name`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Sets the value of {@link CfnFunctionProps#getAutoPublish}
         * @param autoPublish `AWS::CloudFront::Function.AutoPublish`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder autoPublish(java.lang.Boolean autoPublish) {
            this.autoPublish = autoPublish;
            return this;
        }

        /**
         * Sets the value of {@link CfnFunctionProps#getAutoPublish}
         * @param autoPublish `AWS::CloudFront::Function.AutoPublish`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder autoPublish(software.amazon.awscdk.core.IResolvable autoPublish) {
            this.autoPublish = autoPublish;
            return this;
        }

        /**
         * Sets the value of {@link CfnFunctionProps#getFunctionCode}
         * @param functionCode `AWS::CloudFront::Function.FunctionCode`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder functionCode(java.lang.String functionCode) {
            this.functionCode = functionCode;
            return this;
        }

        /**
         * Sets the value of {@link CfnFunctionProps#getFunctionConfig}
         * @param functionConfig `AWS::CloudFront::Function.FunctionConfig`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder functionConfig(software.amazon.awscdk.core.IResolvable functionConfig) {
            this.functionConfig = functionConfig;
            return this;
        }

        /**
         * Sets the value of {@link CfnFunctionProps#getFunctionConfig}
         * @param functionConfig `AWS::CloudFront::Function.FunctionConfig`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder functionConfig(software.amazon.awscdk.services.cloudfront.CfnFunction.FunctionConfigProperty functionConfig) {
            this.functionConfig = functionConfig;
            return this;
        }

        /**
         * Sets the value of {@link CfnFunctionProps#getFunctionMetadata}
         * @param functionMetadata `AWS::CloudFront::Function.FunctionMetadata`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder functionMetadata(software.amazon.awscdk.core.IResolvable functionMetadata) {
            this.functionMetadata = functionMetadata;
            return this;
        }

        /**
         * Sets the value of {@link CfnFunctionProps#getFunctionMetadata}
         * @param functionMetadata `AWS::CloudFront::Function.FunctionMetadata`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder functionMetadata(software.amazon.awscdk.services.cloudfront.CfnFunction.FunctionMetadataProperty functionMetadata) {
            this.functionMetadata = functionMetadata;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnFunctionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnFunctionProps build() {
            return new Jsii$Proxy(name, autoPublish, functionCode, functionConfig, functionMetadata);
        }
    }

    /**
     * An implementation for {@link CfnFunctionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnFunctionProps {
        private final java.lang.String name;
        private final java.lang.Object autoPublish;
        private final java.lang.String functionCode;
        private final java.lang.Object functionConfig;
        private final java.lang.Object functionMetadata;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.name = software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.autoPublish = software.amazon.jsii.Kernel.get(this, "autoPublish", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.functionCode = software.amazon.jsii.Kernel.get(this, "functionCode", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.functionConfig = software.amazon.jsii.Kernel.get(this, "functionConfig", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.functionMetadata = software.amazon.jsii.Kernel.get(this, "functionMetadata", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String name, final java.lang.Object autoPublish, final java.lang.String functionCode, final java.lang.Object functionConfig, final java.lang.Object functionMetadata) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.name = java.util.Objects.requireNonNull(name, "name is required");
            this.autoPublish = autoPublish;
            this.functionCode = functionCode;
            this.functionConfig = functionConfig;
            this.functionMetadata = functionMetadata;
        }

        @Override
        public final java.lang.String getName() {
            return this.name;
        }

        @Override
        public final java.lang.Object getAutoPublish() {
            return this.autoPublish;
        }

        @Override
        public final java.lang.String getFunctionCode() {
            return this.functionCode;
        }

        @Override
        public final java.lang.Object getFunctionConfig() {
            return this.functionConfig;
        }

        @Override
        public final java.lang.Object getFunctionMetadata() {
            return this.functionMetadata;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("name", om.valueToTree(this.getName()));
            if (this.getAutoPublish() != null) {
                data.set("autoPublish", om.valueToTree(this.getAutoPublish()));
            }
            if (this.getFunctionCode() != null) {
                data.set("functionCode", om.valueToTree(this.getFunctionCode()));
            }
            if (this.getFunctionConfig() != null) {
                data.set("functionConfig", om.valueToTree(this.getFunctionConfig()));
            }
            if (this.getFunctionMetadata() != null) {
                data.set("functionMetadata", om.valueToTree(this.getFunctionMetadata()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudfront.CfnFunctionProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnFunctionProps.Jsii$Proxy that = (CfnFunctionProps.Jsii$Proxy) o;

            if (!name.equals(that.name)) return false;
            if (this.autoPublish != null ? !this.autoPublish.equals(that.autoPublish) : that.autoPublish != null) return false;
            if (this.functionCode != null ? !this.functionCode.equals(that.functionCode) : that.functionCode != null) return false;
            if (this.functionConfig != null ? !this.functionConfig.equals(that.functionConfig) : that.functionConfig != null) return false;
            return this.functionMetadata != null ? this.functionMetadata.equals(that.functionMetadata) : that.functionMetadata == null;
        }

        @Override
        public final int hashCode() {
            int result = this.name.hashCode();
            result = 31 * result + (this.autoPublish != null ? this.autoPublish.hashCode() : 0);
            result = 31 * result + (this.functionCode != null ? this.functionCode.hashCode() : 0);
            result = 31 * result + (this.functionConfig != null ? this.functionConfig.hashCode() : 0);
            result = 31 * result + (this.functionMetadata != null ? this.functionMetadata.hashCode() : 0);
            return result;
        }
    }
}

==> cloudfront-1.173.0-sources.jar: software/amazon/awscdk/services/cloudfront/CfnFunctionProps.java <==
package software.amazon.awscdk.services.cloudfront;

/**
 * Properties for defining a `CfnFunction`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.cloudfront.*;
 * CfnFunctionProps cfnFunctionProps = CfnFunctionProps.builder()
 *         .name("name")
 *         // the properties below are optional
 *         .autoPublish(false)
 *         .functionCode("functionCode")
 *         .functionConfig(FunctionConfigProperty.builder()
 *                 .comment("comment")
 *                 .runtime("runtime")
 *                 .build())
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-16T18:50:32.833Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudfront.$Module.class, fqn = "@aws-cdk/aws-cloudfront.CfnFunctionProps")
@software.amazon.jsii.Jsii.Proxy(CfnFunctionProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnFunctionProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * A name to identify the function.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getName();

    /**
     * A flag that determines whether to automatically publish the function to the `LIVE` stage when it’s created.
     * <p>
     * To automatically publish to the <code>LIVE</code> stage, set this property to <code>true</code> .
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getAutoPublish() {
        return null;
    }

    /**
     * The function code.
     * <p>
     * For more information about writing a CloudFront function, see <a href="https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/writing-function-code.html">Writing function code for CloudFront Functions</a> in the <em>Amazon CloudFront Developer Guide</em> .
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getFunctionCode() {
        return null;
    }

    /**
     * Contains configuration information about a CloudFront function.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getFunctionConfig() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnFunctionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnFunctionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnFunctionProps> {
        java.lang.String name;
        java.lang.Object autoPublish;
        java.lang.String functionCode;
        java.lang.Object functionConfig;

        /**
         * Sets the value of {@link CfnFunctionProps#getName}
         * @param name A name to identify the function. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Sets the value of {@link CfnFunctionProps#getAutoPublish}
         * @param autoPublish A flag that determines whether to automatically publish the function to the `LIVE` stage when it’s created.
         *                    To automatically publish to the <code>LIVE</code> stage, set this property to <code>true</code> .
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder autoPublish(java.lang.Boolean autoPublish) {
            this.autoPublish = autoPublish;
            return this;
        }

        /**
         * Sets the value of {@link CfnFunctionProps#getAutoPublish}
         * @param autoPublish A flag that determines whether to automatically publish the function to the `LIVE` stage when it’s created.
         *                    To automatically publish to the <code>LIVE</code> stage, set this property to <code>true</code> .
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder autoPublish(software.amazon.awscdk.core.IResolvable autoPublish) {
            this.autoPublish = autoPublish;
            return this;
        }

        /**
         * Sets the value of {@link CfnFunctionProps#getFunctionCode}
         * @param functionCode The function code.
         *                     For more information about writing a CloudFront function, see <a href="https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/writing-function-code.html">Writing function code for CloudFront Functions</a> in the <em>Amazon CloudFront Developer Guide</em> .
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder functionCode(java.lang.String functionCode) {
            this.functionCode = functionCode;
            return this;
        }

        /**
         * Sets the value of {@link CfnFunctionProps#getFunctionConfig}
         * @param functionConfig Contains configuration information about a CloudFront function.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder functionConfig(software.amazon.awscdk.core.IResolvable functionConfig) {
            this.functionConfig = functionConfig;
            return this;
        }

        /**
         * Sets the value of {@link CfnFunctionProps#getFunctionConfig}
         * @param functionConfig Contains configuration information about a CloudFront function.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder functionConfig(software.amazon.awscdk.services.cloudfront.CfnFunction.FunctionConfigProperty functionConfig) {
            this.functionConfig = functionConfig;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnFunctionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnFunctionProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnFunctionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnFunctionProps {
        private final java.lang.String name;
        private final java.lang.Object autoPublish;
        private final java.lang.String functionCode;
        private final java.lang.Object functionConfig;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.name = software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.autoPublish = software.amazon.jsii.Kernel.get(this, "autoPublish", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.functionCode = software.amazon.jsii.Kernel.get(this, "functionCode", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.functionConfig = software.amazon.jsii.Kernel.get(this, "functionConfig", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.name = java.util.Objects.requireNonNull(builder.name, "name is required");
            this.autoPublish = builder.autoPublish;
            this.functionCode = builder.functionCode;
            this.functionConfig = builder.functionConfig;
        }

        @Override
        public final java.lang.String getName() {
            return this.name;
        }

        @Override
        public final java.lang.Object getAutoPublish() {
            return this.autoPublish;
        }

        @Override
        public final java.lang.String getFunctionCode() {
            return this.functionCode;
        }

        @Override
        public final java.lang.Object getFunctionConfig() {
            return this.functionConfig;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("name", om.valueToTree(this.getName()));
            if (this.getAutoPublish() != null) {
                data.set("autoPublish", om.valueToTree(this.getAutoPublish()));
            }
            if (this.getFunctionCode() != null) {
                data.set("functionCode", om.valueToTree(this.getFunctionCode()));
            }
            if (this.getFunctionConfig() != null) {
                data.set("functionConfig", om.valueToTree(this.getFunctionConfig()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudfront.CfnFunctionProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnFunctionProps.Jsii$Proxy that = (CfnFunctionProps.Jsii$Proxy) o;

            if (!name.equals(that.name)) return false;
            if (this.autoPublish != null ? !this.autoPublish.equals(that.autoPublish) : that.autoPublish != null) return false;
            if (this.functionCode != null ? !this.functionCode.equals(that.functionCode) : that.functionCode != null) return false;
            return this.functionConfig != null ? this.functionConfig.equals(that.functionConfig) : that.functionConfig == null;
        }

        @Override
        public final int hashCode() {
            int result = this.name.hashCode();
            result = 31 * result + (this.autoPublish != null ? this.autoPublish.hashCode() : 0);
            result = 31 * result + (this.functionCode != null ? this.functionCode.hashCode() : 0);
            result = 31 * result + (this.functionConfig != null ? this.functionConfig.hashCode() : 0);
            return result;
        }
    }
}
